@@ -5,5 +5,7 @@ from .bitbucket import Bitbucket as Stash
 from .portfolio import Portfolio
 from .bamboo import Bamboo
 from .crowd import Crowd
+from .service_desk import ServiceDesk
+from .marketplace import MarketPlace
 
-__all__ = ['Confluence', 'Jira', 'Bitbucket', 'Portfolio', 'Bamboo', 'Stash', 'Crowd']
+__all__ = ['Confluence', 'Jira', 'Bitbucket', 'Portfolio', 'Bamboo', 'Stash', 'Crowd', 'ServiceDesk', 'MarketPlace']
